<?php



class DefaultPresenter extends BasePresenter
{

    public $bankNo;
    
    public $tr = array(',' => '.', ' ' => '');
    
    protected function createComponentUpload($name)
    {
        $form = new AppForm($this, $name);
        
        $form->addFile('source', 'CSV zdroj:')
            ->addRule(Form::FILLED);

        $sub = $form->addContainer('details');
        
        $sub->addText('cisloUctu', 'Číslo účtu')
            ->addRule(Form::FILLED);
        $sub->addText('nazevUctu', 'Název účtu');
        $sub->addText('cisloVypisu', 'Číslo výpisu')
            ->addRule(Form::FILLED)
            ->setDefaultValue(date("m"));
        $sub->addDatePicker('datumVypisu', 'Datum výpisu')
            ->setDefaultValue(date("Y-m-d"))
            ->addRule(Form::FILLED)
            ->getControlPrototype()->class('text');
        $sub->addText('zustatek', 'Počáteční zůstatek')
            ->addRule(Form::FILLED);
        
        $form->addSubmit('submit', 'Odeslat')
            ->onClick[] = callback($this, 'convert');

    }
    
    public function convert($button)
    {
        $form = $button->form;

        $session = Environment::getSession('source');
        $session->form = $form['details']->values;
        
        $uploaded = $form['source']->value;
        
        if($uploaded->isOk()){

            $i = 0;
            $source = array();
            if (($handle = fopen($uploaded, "r")) !== FALSE) {
                $source[$i] = array();
                while (($data = fgetcsv($handle, 1000, ";")) !== FALSE) {
                    $num = count($data);
                    for ($c=0; $c < $num; $c++) {
                        $source[$i][$c] = $this->autoUTF($data[$c]);
                        $source[$i][$c] = String::normalize($data[$c]);
                    }
                    $i++;
                }
                fclose($handle);
            }
            
            $session->source = $source;
            
            $this->redirect('abo');
        } else {
            $form->addError('Nepodařilo se nahrát zdrojový soubor');
            return;
        }
        
    }

    public function permuteAccountNo($account)
    {
        $exp = explode('/', $account);
        $account = $exp[0];

        $exp = explode('-', $account);
        if(count($exp) == 1) {
            $exp[] = 000000;
            $exp = array_reverse($exp);
        } else {
            $exp[0] = String::padLeft($exp[0], 6, 0);
        }

        $c = String::padLeft($exp[1], 10, 0);

        return "{$c[9]}{$c[7]}{$c[8]}{$c[5]}{$c[0]}{$c[1]}{$c[2]}{$c[3]}{$c[4]}{$c[6]}{$exp[0]}";
    }
    
    public function getBankNo($account)
    {
        $exp = explode('/', $account);
        return isset($exp[1]) ? $exp[1] : $this->bankNo;
    }
    
    public function toFloat($string)
    {
        return floatval(strtr($string, $this->tr));
    }
    
    public function getCode($amount, $storno)
    {
        $code = 1;
        if($amount > 0) {
            $code = $storno == 'Ne' ? 2 : 4;
        } else {
            $code = $storno == 'Ne' ? 1 : 3;
        }
        
        return $code;
    }
    
    public function actionAbo()
    {
        //$this->setView('abo_orig');
        
        $session = Environment::getSession('source');
        $source = $session->source;
        $form = $session->form;

        $this->bankNo = $this->getBankNo($form['cisloUctu']);

        $md = $dal = 0;
        $result = array();
        foreach(array_slice($source, 1) as $row_id => $row) {
            $row[14] = preg_replace('/\s+/',' ', $row[14]);
            $row[15] = preg_replace('/\s+/',' ', $row[15]);
            
            $result[$row_id][String::webalize('Typ záznamu')] = "075";
            $result[$row_id][String::webalize('Číslo učtu')] = String::padRight(substr($this->permuteAccountNo($form['cisloUctu']), 0, 16), 16, 0);
            $result[$row_id][String::webalize('Číslo protiúčtu')] = String::padRight(substr($this->permuteAccountNo($row[5]), 0, 16), 0, 16);
            $result[$row_id][String::webalize('Číslo dokladu')] = String::padLeft($row[16], 13, 0);
            $result[$row_id][String::webalize('Částka')] = String::padLeft(abs($this->toFloat($row[3])) * 100, 12, 0);
            $result[$row_id][String::webalize('Kód účtování')] = $this->getCode($row[3], $row[13]);
            $result[$row_id][String::webalize('VS')] = String::padLeft($row[2], 10, 0);
            $result[$row_id][String::webalize('KS')] = substr(String::padLeft($this->getBankNo($row[5]), 6, 0), 0, 6) . substr(String::padLeft($row[11], 4, 0), 0, 4);
            $result[$row_id][String::webalize('SS')] = String::padLeft($row[12], 10, 0);
            $result[$row_id][String::webalize('Valuta')] = TemplateHelpers::date($row[1], "dmy");
            $result[$row_id][String::webalize('Dopl. údaj')] = $this->utf2win(mb_substr(String::padRight($this->autoUTF($row[15] ? $row[15] : $row[14]), 20, ' '), 0, 20));
            $result[$row_id][String::webalize('Kód změny položky')] = "0";
            $result[$row_id][String::webalize('Druh dat')] = "11" . String::padLeft($this->toFloat($row[3]) > 0 ? 2 : 1, 2, 0);
            $result[$row_id][String::webalize('Datum splatnosti')] = TemplateHelpers::date($row[6], "dmy");
            
            $obrat = $this->toFloat($row[3]);
            $obrat > 0 ? $dal += abs($obrat) : $md += abs($obrat);
        }
        $this->template->result = array_reverse($result);
        $this->template->rows = $source;

        $staryZustatek = $this->toFloat($form['zustatek']);
        $novyZustatek = $staryZustatek + ($dal - $md);
        
        $prev_date = clone $form['datumVypisu'];
        date_modify($prev_date, '-1 month');
        
        $header[String::webalize("Typ záznamu")] = "074";
        $header[String::webalize("Číslo účtu")] = String::padRight(substr($this->permuteAccountNo($form['cisloUctu']), 0, 16), 16, 0);
        $header[String::webalize("Zkrácený název klienta")] = String::padRight(substr($this->utf2win($form['nazevUctu']), 0, 20), 20, ' ');
        $header[String::webalize("Dat. Starého zůstatku")] = TemplateHelpers::date(date_format($prev_date, 'Y/m/t'), "dmy");
        $header[String::webalize("Starý zůstatek")] = String::padLeft(abs($staryZustatek) * 100, 14, 0);
        $header[String::webalize("Znaménko st. zůstatku")] = $staryZustatek > 0 ? "+" : "-";
        $header[String::webalize("Nový zůstatek")] = String::padLeft(abs($novyZustatek) * 100, 14, 0);
        $header[String::webalize("Znaménko nového zůstatku")] = $novyZustatek > 0 ? "+" : "-";
        $header[String::webalize("Obraty debet MD")] = String::padLeft(abs($md) * 100, 14, 0);
        $header[String::webalize("Znaménko obratů debet")] = $md > 0 ? "+" : "-";
        $header[String::webalize("Obraty kredit")] = String::padLeft(abs($dal) * 100, 14, 0);
        $header[String::webalize("Znaménko obratů kredit")] = $dal > 0 ? "+" : "-";
        $header[String::webalize("Poř. č. výpisu")] = String::padLeft($form['cisloVypisu'], 3, 0);
        $header[String::webalize("Datum zaúčtování")] = TemplateHelpers::date(date_format($form['datumVypisu'], 'Y/m/d'), "dmy");
        $header[String::webalize("Filler")] = str_repeat(' ', 14);
        
        $this->template->h = $header;
        
        header('Content-Type: text/plain; charset=windows-1250');
        header('Content-Disposition: attachment; filename="export_ABO_' . date("d-m-y") . '.gpc"');
        header('Cache-Control: max-age=0');/**/
        
    }
    
}
